Index: trunk/Ohana/src/libdvo/include/dvo.h
===================================================================
--- trunk/Ohana/src/libdvo/include/dvo.h	(revision 39480)
+++ trunk/Ohana/src/libdvo/include/dvo.h	(revision 39521)
@@ -174,13 +174,16 @@
   ID_OBJ_FEW             = 0x00000001, // used within relphot: skip star
   ID_OBJ_POOR            = 0x00000002, // used within relphot: skip star
+
   // NOTE: bits used for object classification:
   ID_OBJ_ICRF_QSO        = 0x00000004, // object IDed with known ICRF quasar (may have ICRF position measurement)
-  ID_OBJ_OTHEF_QSO       = 0x00000008, // identified as likely QSO (Hernitschek et al 2015), without ICRF reference data
-  ID_OBJ_TRANSIENT       = 0x00000010, // identified as a non-periodic (stationary) transient
-  ID_OBJ_VARIABLE        = 0x00000020, // identified as a periodic variable
-  ID_OBJ_RRLYRA          = 0x00000040, // identified as likely RR Lyra (Hernitschek et al 2015)
-  ID_OBJ_HAS_SOLSYS_DET  = 0x00000080, // identified with a known solar-system object (asteroid or other)
-  ID_OBJ_ALL_SOLSYS_DET  = 0x00000100, // identified with a known solar-system object (asteroid or other)
-  // bits 0x00000200 - 0x00000400 are currently unused
+  ID_OBJ_HERN_QSO_P60    = 0x00000008, // identified as likely QSO (Hernitschek et al 2015), P_QSO = 0.60
+  ID_OBJ_HERN_QSO_P05    = 0x00000010, // identified as possible QSO (Hernitschek et al 2015), P_QSO = 0.05
+  ID_OBJ_HERN_RRL_P60    = 0x00000020, // identified as likely  RR Lyra (Hernitschek et al 2015), P_RRLyra = 0.60
+  ID_OBJ_HERN_RRL_P05    = 0x00000040, // identified as possible RR Lyra (Hernitschek et al 2015), P_RRLyra = 0.05
+  ID_OBJ_HERN_VARIABLE   = 0x00000080, // identified as a variable based on ChiSq (Hernitschek et al 2015)
+  ID_OBJ_TRANSIENT       = 0x00000100, // identified as a non-periodic (stationary) transient
+  ID_OBJ_HAS_SOLSYS_DET  = 0x00000200, // identified with a known solar-system object (asteroid or other)
+  ID_OBJ_MOST_SOLSYS_DET = 0x00000400, // most detections from a known solar-system object
+
   // NOTE: bits used for astrometry analysis
   ID_OBJ_LARGE_PM        = 0x00000800, // star with large proper motion
@@ -196,4 +199,5 @@
   ID_OBJ_MEAN_FOR_STACK  = 0x00200000, // mean astrometry could not be measured
   ID_OBJ_BAD_PM          = 0x00400000, // failure to measure proper-motion model
+
   // NOTE: bits used for photometry analysis
   ID_OBJ_EXT             = 0x00800000, // extended in our data (eg, PS)
